#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import codecs
from setuptools import setup, find_packages


with open("README.md", "r") as fh:
    long_description = fh.read()

def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return codecs.open(file_path, encoding='utf-8').read()


# Add your dependencies in requirements.txt
# Note: you can add test-specific requirements in tox.ini
requirements = []
with open('requirements.txt') as f:
    for line in f:
        stripped = line.split("#")[0].strip()
        if len(stripped) > 0:
            requirements.append(stripped)


# https://github.com/pypa/setuptools_scm
use_scm = {"write_to": "napari_webcam/_version.py"}

setup(
    name='napari_webcam',
    author='Robert Haase',
    author_email='robert.haase@tu-dresden.de',
    license='BSD-3',
    url='https://github.com/haesleinhuepf/napari-webcam',
    description='Use your webcam from napari',
    long_description_content_type='text/markdown',
    long_description=long_description,
    packages=find_packages(),
    python_requires='>=3.6',
    install_requires=requirements,
    #use_scm_version=use_scm,
    version="0.1.11",
    setup_requires=['setuptools_scm'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Framework :: napari',
        'Topic :: Software Development :: Testing',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: BSD License',
    ],
    entry_points={
        'napari.plugin': [
            'napari_webcam = napari_webcam',
        ],
    },
)
